summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp')
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp
index 4c10bd53..ba14f404 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-core/parser.cpp
@@ -22,7 +22,7 @@
TODO:
For XMPP::Parser to be "perfect", some things must be solved/changed in the
- Qt library:
+ TQt library:
- Fix weird TQDomElement::haveAttributeNS() bug (patch submitted to
Trolltech on Aug 31st, 2003).
@@ -31,7 +31,7 @@
the final '>' is reached.
- Fix incremental parsing bugs in TQXmlSimpleReader. At the moment, the
only bug I've found is related to attribute parsing, but there might
- be more (search for '###' in $QTDIR/src/xml/qxml.cpp).
+ be more (search for '###' in $TQTDIR/src/xml/qxml.cpp).
We have workarounds for all of the above problems in the code below.
@@ -44,7 +44,7 @@
- Make TQXmlInputSource capable of accepting data incrementally, to ensure
proper text encoding detection and processing over a network. This is
technically not a bug, as we have our own subclass below to do it, but
- it would be nice if Qt had this already.
+ it would be nice if TQt had this already.
*/
#include"parser.h"
@@ -61,7 +61,7 @@ static bool qt_bug_have;
//----------------------------------------------------------------------------
// StreamInput
//----------------------------------------------------------------------------
-class StreamInput : public QXmlInputSource
+class StreamInput : public TQXmlInputSource
{
public:
StreamInput()
@@ -232,10 +232,10 @@ private:
if(mightChangeEncoding) {
while(1) {
- int n = out.find('<');
+ int n = out.tqfind('<');
if(n != -1) {
// we need a closing bracket
- int n2 = out.find('>', n);
+ int n2 = out.tqfind('>', n);
if(n2 != -1) {
++n2;
TQString h = out.mid(n, n2-n);
@@ -278,8 +278,8 @@ private:
if(h.left(5) != "<?xml")
return "";
- int endPos = h.find(">");
- int startPos = h.find("encoding");
+ int endPos = h.tqfind(">");
+ int startPos = h.tqfind("encoding");
if(startPos < endPos && startPos != -1) {
TQString encoding;
do {
@@ -335,7 +335,7 @@ private:
bool checkForBadChars(const TQString &s)
{
- int len = s.find('<');
+ int len = s.tqfind('<');
if(len == -1)
len = s.length();
else
@@ -354,7 +354,7 @@ private:
//----------------------------------------------------------------------------
namespace XMPP
{
- class ParserHandler : public QXmlDefaultHandler
+ class ParserHandler : public TQXmlDefaultHandler
{
public:
ParserHandler(StreamInput *_in, TQDomDocument *_doc)
@@ -465,7 +465,7 @@ namespace XMPP
current = TQDomElement();
}
else
- current = current.parentNode().toElement();
+ current = current.tqparentNode().toElement();
}
if(in->lastRead() == '/')
@@ -610,7 +610,7 @@ TQString Parser::Event::nsprefix(const TQString &s) const
return (*it2);
++it2;
}
- return TQString::null;
+ return TQString();
}
TQString Parser::Event::namespaceURI() const
@@ -737,7 +737,7 @@ Parser::Parser()
{
d = new Private;
// check for evil bug in Qt <= 3.2.1
if(!qt_bug_check) {
qt_bug_check = true;
TQDomElement e = d->doc->createElementNS("someuri", "somename");
@@ -737,7 +737,7 @@ Parser::Parser()
{
d = new Private;
- // check for evil bug in Qt <= 3.2.1
+ // check for evil bug in TQt <= 3.2.1
if(!qt_bug_check) {
qt_bug_check = true;